@@ -493,7 +493,11 @@ void CalcEngine::CosHyp(const KNumber &input)
     if (input.type() == KNumber::TYPE_ERROR) {
         if (input == KNumber::NaN)         last_number_ = KNumber::NaN;
         if (input == KNumber::PosInfinity) last_number_ = KNumber::PosInfinity;
-        if (input == KNumber::NegInfinity) last_number_ = KNumber::NegInfinity;
+		// YES, this should be *positive* infinity. We mimic the behavior of 
+		// libc which says the following for cosh
+		//
+		// "If x is positive infinity or negative infinity, positive infinity is returned."
+        if (input == KNumber::NegInfinity) last_number_ = KNumber::PosInfinity;
         return;
     }
 
